Who is using Math.NET Numerics?
===============================

*This page collects anything that references and/or uses Math.NET Numerics.
Feel free to [add, edit or remove your own work](https://github.com/mathnet/mathnet-numerics/blob/master/docs/content/Users.md) by submitting a pull request.*

Open Source
-----------

* [MyMediaLite Recommender System Library](http://www.ismll.uni-hildesheim.de/mymedialite/)
* [FermiSim, studying potential solutions to the Fermi paradox via computational simulation of models for space colonisation](https://launchpad.net/fermisim)
* [Three-Dimensional Model Shape Description and Retrieval Based on LightField Descriptors](https://code.google.com/p/lightfieldretrieval/)
* [Virtual Photonics Technology Initiative](https://virtualphotonics.codeplex.com/)
* [SharpFE: a lightweight, expandable finite element solver for .net](https://github.com/iainsproat/SharpFE)
* [FsLab: Machine Learning and Data Science with F#](http://fslab.org/)
* [Simple FM Matrix](http://cs.mcgill.ca/~ryang6/simplefmmatrix/)
* [mathlib.net](http://mathlibproject.codeplex.com/)
* [PhysicsPad](https://github.com/Amichai/PhysicsPad)
* [DRFCSharp: Discriminative Random Fields implementation for C#](https://github.com/exitmouse/drfcsharp)
* [SharpBench: Benchmarking system for Mono/.Net](https://github.com/ranma42/SharpBench)
* [Behavioral Rating of Dancing Human Crowds based on Motion Patterns](http://emotiondetection.codeplex.com/)
* [NPSS Framework for numerical computations of Laguerre series](https://www.openhub.net/p/npss)
* [FIRST Robotics Scout App](https://frcscout.codeplex.com/)
* [Improvisation: Automatic Music Composition and Melody Generation](https://github.com/ArmenAg/Improvisation)
* [Epicycle Math Library](https://github.com/open-epicycle/Epicycle.Math-cs)
* [LitePlacer machine user interface and control software](https://github.com/jkuusama/LitePlacer)
* [Math.Net PowerShell](http://mathnetpowershell.codeplex.com/) (unaffiliated)
* [Math.NET Symbolics](http://symbolics.mathdotnet.com) and other [Math.NET](http://www.mathdotnet.com) projects.

Closed Source
-------------

* [C# Pad](http://www.csharppad.com)
* [Instarange Simulation](http://instarange.com) by Instarange (Pty) Ltd
* [SpectraFox](http://www.spectrafox.com/) STM / AFM spectroscopy analysis
* [Colymp](http://colymp.com/) Color Management Software
* [ILNumerics](http://ilnumerics.net/)
* [GazeSpeaker](http://www.gazespeaker.org) Free software to help people with disabilities
* [ModVal.org](http://www.modval.org) Quant model repository for regulatory and internal model validation.
* At least half of the hearing aid market for their software to fit
  their hearing instruments to a patient's actual hearing loss.

Blogs, Tutorials & Examples
---------------------------

* [Yin Zhu: Tutorial: Using Math.NET Numerics in F#](http://msdn.microsoft.com/en-us/library/hh304363.aspx)
* [Don Syme: Getting Started with Math.NET and F# Programming](http://blogs.msdn.com/b/dsyme/archive/2012/07/06/getting-started-with-math-net-and-f-programming.aspx)
* [Libor Tinka: Linear and Nonlinear Least-Squares with Math.NET](http://www.imagingshop.com/articles/least-squares)
* [Carl Nolan: Co-occurrence Approach to an Item Based Recommender](http://code.msdn.microsoft.com/Co-occurrence-Approach-to-57027db7)
* [Gustavo Guerra: F# as a Octave/Matlab Replacement for Machine Learning](http://functionalflow.co.uk/blog/2011/10/27/f-as-a-octavematlab-replacement-for-machine-learning/)
* [Mathias Brandewinder: Simplify data with SVD and Math.NET in F#](http://clear-lines.com/blog/post/Simplify-data-with-SVD-and-MathNET-in-FSharp.aspx)
* [Mathias Brandewinder: Recommendation Engine using Math.NET, SVD and F#](http://clear-lines.com/blog/post/Recommendation-Engine-with-SVD-and-MathNET-in-FSharp.aspx)
* [Thomas Jungblut: Stochastic Logistic Regression in F#](http://codingwiththomas.blogspot.ch/2014/05/stochastic-logistic-regression-in-f.html)
* [Calvin Bottoms: Set-Based Operations: They’re Not Just For Databases](http://calvinbottoms.blogspot.ch/2012/01/set-based-operations-theyre-not-just.html)
* [Chao-Jen Chen: F#: Simulate entire GBM path](http://programmingcradle.blogspot.ch/2012/09/f-simulate-entire-gbm-path.html)
* [Chao-Jen Chen: F#: K-S test on final prices of GBM paths ](http://programmingcradle.blogspot.ch/2012/09/f-k-s-test-on-final-prices-of-gbm-paths.html)
* [Dawid Kowalski: F#, Deedle and Computational Investing](http://dkowalski.com/blog/archive/2014/01/11/f-deedle-and-computational-investing.aspx)
* [Christoph Rüegg: Linear Regression With Math.NET Numerics](http://christoph.ruegg.name/blog/linear-regression-mathnet-numerics.html)

Books
-----

* Expert F# 3.0 *by Don Syme, Adam Granicz, Antonio Cisternino*. Apress.
* F# for Quantitative Finance *by Johan Astborg*. Packt Publishing.
* F# Deep Dives *by Tomas Petricek, Philip Trelford*. Manning Publications.
* Computer Graphics: Principles and Practices *by John F. Hughes, Andries van Dam, Morgan McGuire, David F. Sklar, James D. Foley, Steven K. Feiner, Kurt Akeley*. Addison-Wesley Professional, 3rd edition.

Papers and Thesis
-----------------

* Czarnowska, Lucyna; Litwin, Wojciech; Stanek, Wojciech (2015). *Selection of Numerical Methods and their Application to the Thermo-Ecological Life Cycle Cost of Heat Exchanger Components*. Silesian University of Technology.
* Schmollinger, Stefan; Mülhaus, Timo; et al (2014). *Nitrogen-Sparing Mechanisms in Chlamydomonas Affect the Transcriptome, the Proteome, and Photosynthetic Metabolism.* The Plant Cell. DOI 10.1105/tpc.113.122523
* Mettler, Tabea; Mülhaus, Timo; et al (2014). *Systems Analysis of the Response of Photosynthesis, Metabolism, and Growth to an Increase in Irradiance in the Photosynthetic Model Organism Chlamydomonas reinhardtii.* The Plant Cell. DOI 10.1105/tpc.114.124537.
* Blahút, Jozef (2014). *Design and Implementation of Application for Measured Data Processing*. Brno University of Technology.
* Mueller, Caitlin; Ochsendorf John (2013). *From Analysis to Design: A New Computational Strategy for Structural Creativity.* Massachusetts Institute of Technology. 2nd International Workshop on Design in Civil and Environmental Engineering.
* Puwalowski, Mateusz (2013). *Ukryte Indeksowanie Semantyczne.* Uniwersytet Gdanski.
* Botter, R (2013). *Efficiënt begroten met historische projectgegevens.* Technische Universiteit Eindhoven.
* Parma, Alessio (2013). *Una libreria per la simulazione a eventi discreti in .NET.* Università Degli Studi Di Genova.
* Singh, Rohit; Gulwani, Sumit; Rajamani Sriram (2012). *Automatically Generating Algebra Problems.* Microsoft Research. Association for the Advancement of Artificial Intelligence.
* Grahl Pereira, André; Petry, Adriano (2012). *Data Assimilation using NeuroEvolution of Augmenting Topologies.* IJCNN. WCCI 2012 IEEE World Congress on Computational Intelligence.
* Lauppe, Joost (2012). *Reinforcement Toolbox: A Parametric Reinforcement Modeling Tool for Curved Surface Structures.* Delft University of Technology.
* Lundström, Lukas (2012). *Weather data for building simulation: New actual weather files for North Europe combining observed weather and modeled solar radiation.* School of Sustainable Development of Society and Technology, HST.
* AT Council (2012). *Seismic Performance Assessment of Buildings Volume 2 - Implementation Guide.* FEMA, U.S. Department of Homeland Security.
* Ma, Jiangshan (2012). *Hyperpath-based Strategic Route Guidance Considering Travel Time Uncertainty.* Transportation Studies Unit, Tokyo Institute of Transportation.
* Fisher, Michael (2012). *Research and Development of a VST Plugin for the Autonomous Post Production of a Stereo Piano Recording.* University of Huddersfield.
* Williams, Liam (2012). *Spotting The Wisdom In The Crowds.* Imperial College London.
* Schräder, Niklas (2011). *Detecting falls and poses in image silhouettes (M.Sc).* Chalmers University of Technology, Gothenburg, Sweden. ISSN 1652-8557.
* Nelson, Peter (2011). *3D Mapping for Robotic Search and Rescue.* New College.
* Adelson, Michael (2011). *Emotiv Experimenter: An experimentation and mind-reading application for the Emotiv EPOC.* Princeton University.
* Schindlberger, Michael (2011). *Elastic Properties of Growing 2D Foam (M.Sc).* University of Zurich.
* Krejcar, Ondrej; Jirka, Jakub; Janckulik, Dalibor (2011). *Use of Mobile Phones as Intelligent Sensors for Sound Input Analysis and Sleep State Detection.* Sensors (11): 6037–6055. ISSN 1424-8220.
* Keglevic, Manuel; Schulz, Thomas (2011). *NoNoise - Music Library Visualization.* Vienna University of Technology.
* Kraus, Jan; Bubla, Viktor; Kukacka, Leos (2011). *Data Modeling for Reduction of Volume in Large Archives of Power Quality Data.* 21st International Conference on Electricity Distribution. TUL CZ.
* Ferreira, André Filipe Mateus. *SoundLog: Make More Noise (M.Sc).* Universidade Técnica de Lisboa.
* Nunes, José; Sá, Luis; Perdigão, Fernando (2011). *Talking Avatar for Web-based Interfaces.* Instituto de Telecomunicações, Coimbra, Portugal.
* Miller, Justin (2010). *Design of a Wireless Acquisition System for a Digital Stethoscope (B.Sc).* University of Southern Queensland.
* Skrehota, Ondrej (2010). *Quantitative structure-property relationship modeling algorithms, challenges and IT solutions.* Masaryk University.
* LÍŠKA, Ondrej; ŽIDEK, Kamil (2010). *Accelerometers usability for danger tilt off-highway vehicles and signal filtration with kalman filter.* Journal of applied science in the thermodynamics and fluid mechanics 4 (2): 1–6. ISSN 1802-9388.
* Team Limawai (2010). *Ka`imiolakai ROV.* 2010 MATE International UROV Competition. Kapi`olani Community College.
* Hebel, Tobias (2010). *Location Provider.* Universität Koblenz Landau.
* Bischoff, Sebastian (2009). *Konzeption und Umsetzung einer RIA zur untersuchungsbegleitenden Erfassung von RNFLT-Scans und Untersuchung von Klassifikatoren für die diagnostische Unterstützung bei neurodegenerativen Erkrankungen am Beispiel der Multiplen Sklerose.* Fachhochschule Brandenburg.
